import { ArrowParens, TrailingComma } from 'projen/lib/javascript';
import { publishToRegistries, TerraformModule } from 'projen-cdktf-hybrid-construct';

const moduleVersion = '0.9.4';
const commonIgnore = ['.idea', '.vscode'];
const name = 'cdktf-metaflow-aws';

const project = new TerraformModule({
  author: 'Bryan Galvin',
  authorAddress: 'bcgalvin@gmail.com',
  defaultReleaseBranch: 'main',
  devDeps: ['projen-cdktf-hybrid-construct'],
  name: name,
  repositoryUrl: 'https://github.com/bcgalvin/cdktf-metaflow-aws.git',
  cdktfVersion: '0.17.0',
  typescriptVersion: '^5.1.3',
  terraformModules: [
    {
      name: 'metaflow',
      source: 'outerbounds/metaflow/aws',
      version: `~> ${moduleVersion}`,
    },
    {
      name: 'metaflow_common',
      source: 'outerbounds/metaflow/aws//modules/common',
      version: `~> ${moduleVersion}`,
    },
    {
      name: 'metaflow_computation',
      source: 'outerbounds/metaflow/aws//modules/computation',
      version: `~> ${moduleVersion}`,
    },
    {
      name: 'metaflow_datastore',
      source: 'outerbounds/metaflow/aws//modules/datastore',
      version: `~> ${moduleVersion}`,
    },
    {
      name: 'metaflow_metadata-service',
      source: 'outerbounds/metaflow/aws//modules/metadata-service',
      version: `~> ${moduleVersion}`,
    },

    {
      name: 'metaflow_step-functions',
      source: 'outerbounds/metaflow/aws//modules/step-functions',
      version: `~> ${moduleVersion}`,
    },

    {
      name: 'metaflow_ui',
      source: 'outerbounds/metaflow/aws//modules/ui',
      version: `~> ${moduleVersion}`,
    },
  ],
  prettier: true,
  prettierOptions: {
    settings: {
      printWidth: 120,
      trailingComma: TrailingComma.ALL,
      arrowParens: ArrowParens.ALWAYS,
      singleQuote: true,
    },
  },
  eslintOptions: {
    dirs: ['src'],
    ignorePatterns: ['src/terraformModules.ts'], // permissions issue w projen plugin
  },
  // Ignore files
  gitignore: commonIgnore,
  // publishing
  release: true,
  projectId: 'cdktf-metaflow-aws',
  ...publishToRegistries({
    name: 'cdktf-metaflow-aws',
    namespace: 'bcgalvin',
    registries: ['npm'],
  }),
  publishToPypi: {
    distName: name,
    module: name.replace(/-/g, '_'),
  },
});

project.synth();
