import { TerraformModule, TerraformModuleUserConfig } from 'cdktf';
import { Construct } from 'constructs';
export interface MetaflowConfig extends TerraformModuleUserConfig {
    /**
     * List of CIDRs we want to grant access to our Metaflow Metadata Service. Usually this is our VPN's CIDR blocks.
     * @default
     */
    readonly accessListCidrBlocks?: string[];
    /**
     * AWS Batch Compute Type ('ec2', 'fargate')
     * @default ec2
     */
    readonly batchType?: string;
    /**
     * Desired Starting VCPUs for Batch Compute Environment [0-16] for EC2 Batch Compute Environment (ignored for Fargate)
     * @default 8
     */
    readonly computeEnvironmentDesiredVcpus?: number;
    /**
     * CIDR blocks to which egress is allowed from the Batch Compute environment's security group
     * @default 0.0.0.0/0
     */
    readonly computeEnvironmentEgressCidrBlocks?: string[];
    /**
     * The instance types for the compute environment
     * @default c4.large,c4.xlarge,c4.2xlarge,c4.4xlarge,c4.8xlarge
     */
    readonly computeEnvironmentInstanceTypes?: string[];
    /**
     * Maximum VCPUs for Batch Compute Environment [16-96]
     * @default 64
     */
    readonly computeEnvironmentMaxVcpus?: number;
    /**
     * Minimum VCPUs for Batch Compute Environment [0-16] for EC2 Batch Compute Environment (ignored for Fargate)
     * @default 8
     */
    readonly computeEnvironmentMinVcpus?: number;
    /**
     * Provisions infrastructure for custom Amazon ECR container registry if enabled
     */
    readonly enableCustomBatchContainerRegistry?: boolean;
    /**
     * Provisions infrastructure for step functions if enabled
     */
    readonly enableStepFunctions: boolean;
    /**
     * Additional environment variables for UI backend container
     * @default [object Object]
     * The property type contains a map, they have special handling, please see {@link cdk.tf/module-map-inputs the docs}
     */
    readonly extraUiBackendEnvVars?: {
        [key: string]: string;
    };
    /**
     * Additional environment variables for UI static app
     * @default [object Object]
     * The property type contains a map, they have special handling, please see {@link cdk.tf/module-map-inputs the docs}
     */
    readonly extraUiStaticEnvVars?: {
        [key: string]: string;
    };
    /**
     * Empty S3 bucket before destroying via terraform destroy
     */
    readonly forceDestroyS3Bucket?: boolean;
    /**
     * IAM Partition (Select aws-us-gov for AWS GovCloud, otherwise leave as is)
     * @default aws
     */
    readonly iamPartition?: string;
    /**
     * Whether the metadata service is available. Can be 'enabled' or 'disabled'
     * @default enabled
     */
    readonly launchTemplateHttpEndpoint?: string;
    /**
     * The desired HTTP PUT response hop limit for instance metadata requests. Can be an integer from 1 to 64
     * @default 2
     */
    readonly launchTemplateHttpPutResponseHopLimit?: number;
    /**
     * Whether or not the metadata service requires session tokens, also referred to as Instance Metadata Service Version 2 (IMDSv2). Can be 'optional' or 'required'
     * @default optional
     */
    readonly launchTemplateHttpTokens?: string;
    /**
     * Container image for metadata service
     */
    readonly metadataServiceContainerImage?: string;
    /**
     * Enable basic auth for API Gateway? (requires key export)
     * @default true
     */
    readonly metadataServiceEnableApiBasicAuth?: boolean;
    /**
     * Enable API Gateway for public metadata service endpoint
     * @default true
     */
    readonly metadataServiceEnableApiGateway?: boolean;
    /**
     * string prefix for all resources
     * @default metaflow
     */
    readonly resourcePrefix?: any;
    /**
     * string suffix for all resources
     */
    readonly resourceSuffix?: any;
    /**
     * First subnet used for availability zone redundancy
     */
    readonly subnet1Id: string;
    /**
     * Second subnet used for availability zone redundancy
     */
    readonly subnet2Id: string;
    /**
     * aws tags
     * The property type contains a map, they have special handling, please see {@link cdk.tf/module-map-inputs the docs}
     */
    readonly tags: {
        [key: string]: string;
    };
    /**
     * Defines whether the ALB for the UI is internal
     */
    readonly uiAlbInternal?: boolean;
    /**
     * List of CIDRs we want to grant access to our Metaflow UI Service. Usually this is our VPN's CIDR blocks.
     * @default
     */
    readonly uiAllowList?: string[];
    /**
     * SSL certificate for UI. If set to empty string, UI is disabled.
     */
    readonly uiCertificateArn?: string;
    /**
     * Container image for the UI frontend app
     */
    readonly uiStaticContainerImage?: string;
    /**
     * The VPC CIDR blocks that we'll access list on our Metadata Service API to allow all internal communications
     */
    readonly vpcCidrBlocks: string[];
    /**
     * The id of the single VPC we stood up for all Metaflow resources to exist in.
     */
    readonly vpcId: string;
    /**
     * Enable public IP assignment for the Metadata Service. Typically you want this to be set to true if using public subnets as subnet1_id and subnet2_id, and false otherwise
     */
    readonly withPublicIp: boolean;
}
/**
 * Defines an Metaflow based on a Terraform module
 *
 * Docs at Terraform Registry: {@link https://registry.terraform.io/modules/outerbounds/metaflow/aws/~> 0.9.4 outerbounds/metaflow/aws}
 */
export declare class Metaflow extends TerraformModule {
    private readonly inputs;
    constructor(scope: Construct, id: string, config: MetaflowConfig);
    get accessListCidrBlocks(): string[] | undefined;
    set accessListCidrBlocks(value: string[] | undefined);
    get batchType(): string | undefined;
    set batchType(value: string | undefined);
    get computeEnvironmentDesiredVcpus(): number | undefined;
    set computeEnvironmentDesiredVcpus(value: number | undefined);
    get computeEnvironmentEgressCidrBlocks(): string[] | undefined;
    set computeEnvironmentEgressCidrBlocks(value: string[] | undefined);
    get computeEnvironmentInstanceTypes(): string[] | undefined;
    set computeEnvironmentInstanceTypes(value: string[] | undefined);
    get computeEnvironmentMaxVcpus(): number | undefined;
    set computeEnvironmentMaxVcpus(value: number | undefined);
    get computeEnvironmentMinVcpus(): number | undefined;
    set computeEnvironmentMinVcpus(value: number | undefined);
    get enableCustomBatchContainerRegistry(): boolean | undefined;
    set enableCustomBatchContainerRegistry(value: boolean | undefined);
    get enableStepFunctions(): boolean;
    set enableStepFunctions(value: boolean);
    get extraUiBackendEnvVars(): {
        [key: string]: string;
    } | undefined;
    set extraUiBackendEnvVars(value: {
        [key: string]: string;
    } | undefined);
    get extraUiStaticEnvVars(): {
        [key: string]: string;
    } | undefined;
    set extraUiStaticEnvVars(value: {
        [key: string]: string;
    } | undefined);
    get forceDestroyS3Bucket(): boolean | undefined;
    set forceDestroyS3Bucket(value: boolean | undefined);
    get iamPartition(): string | undefined;
    set iamPartition(value: string | undefined);
    get launchTemplateHttpEndpoint(): string | undefined;
    set launchTemplateHttpEndpoint(value: string | undefined);
    get launchTemplateHttpPutResponseHopLimit(): number | undefined;
    set launchTemplateHttpPutResponseHopLimit(value: number | undefined);
    get launchTemplateHttpTokens(): string | undefined;
    set launchTemplateHttpTokens(value: string | undefined);
    get metadataServiceContainerImage(): string | undefined;
    set metadataServiceContainerImage(value: string | undefined);
    get metadataServiceEnableApiBasicAuth(): boolean | undefined;
    set metadataServiceEnableApiBasicAuth(value: boolean | undefined);
    get metadataServiceEnableApiGateway(): boolean | undefined;
    set metadataServiceEnableApiGateway(value: boolean | undefined);
    get resourcePrefix(): any | undefined;
    set resourcePrefix(value: any | undefined);
    get resourceSuffix(): any | undefined;
    set resourceSuffix(value: any | undefined);
    get subnet1Id(): string;
    set subnet1Id(value: string);
    get subnet2Id(): string;
    set subnet2Id(value: string);
    get tags(): {
        [key: string]: string;
    };
    set tags(value: {
        [key: string]: string;
    });
    get uiAlbInternal(): boolean | undefined;
    set uiAlbInternal(value: boolean | undefined);
    get uiAllowList(): string[] | undefined;
    set uiAllowList(value: string[] | undefined);
    get uiCertificateArn(): string | undefined;
    set uiCertificateArn(value: string | undefined);
    get uiStaticContainerImage(): string | undefined;
    set uiStaticContainerImage(value: string | undefined);
    get vpcCidrBlocks(): string[];
    set vpcCidrBlocks(value: string[]);
    get vpcId(): string;
    set vpcId(value: string);
    get withPublicIp(): boolean;
    set withPublicIp(value: boolean);
    get metaflowBatchJobQueueOutput(): string;
    get metaflowDatastoreSysrootS3Output(): string;
    get metaflowDatatoolsS3RootOutput(): string;
    get metaflowEcsS3AccessIamRoleOutput(): string;
    get metaflowEventsSfnAccessIamRoleOutput(): string;
    get metaflowServiceInternalUrlOutput(): string;
    get metaflowServiceUrlOutput(): string;
    get metaflowSfnDynamoDbTableOutput(): string;
    get metaflowSfnIamRoleOutput(): string;
    get apiGatewayRestApiIdKeyIdOutput(): string;
    get batchComputeEnvironmentSecurityGroupIdOutput(): string;
    get datastoreS3BucketKmsKeyArnOutput(): string;
    get metadataSvcEcsTaskRoleArnOutput(): string;
    get metaflowApiGatewayRestApiIdOutput(): string;
    get metaflowBatchContainerImageOutput(): string;
    get metaflowProfileJsonOutput(): string;
    get metaflowS3BucketArnOutput(): string;
    get metaflowS3BucketNameOutput(): string;
    get migrationFunctionArnOutput(): string;
    get uiAlbArnOutput(): string;
    get uiAlbDnsNameOutput(): string;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
