import { TerraformModule, TerraformModuleUserConfig } from 'cdktf';
import { Construct } from 'constructs';
export interface MetaflowComputationConfig extends TerraformModuleUserConfig {
    /**
     * AWS Batch Compute Type ('ec2', 'fargate')
     * @default ec2
     */
    readonly batchType?: string;
    /**
     * Additional security group ids to apply to the Batch Compute environment
     * @default
     */
    readonly computeEnvironmentAdditionalSecurityGroupIds?: string[];
    /**
     * Allocation strategy for Batch Compute environment (BEST_FIT, BEST_FIT_PROGRESSIVE, SPOT_CAPACITY_OPTIMIZED)
     * @default BEST_FIT
     */
    readonly computeEnvironmentAllocationStrategy?: string;
    /**
     * Desired Starting VCPUs for Batch Compute Environment [0-16] for EC2 Batch Compute Environment (ignored for Fargate)
     */
    readonly computeEnvironmentDesiredVcpus: number;
    /**
     * CIDR blocks to which egress is allowed from the Batch Compute environment's security group
     * @default 0.0.0.0/0
     */
    readonly computeEnvironmentEgressCidrBlocks?: string[];
    /**
     * The instance types for the compute environment as a comma-separated list
     */
    readonly computeEnvironmentInstanceTypes: string[];
    /**
     * Maximum VCPUs for Batch Compute Environment [16-96]
     */
    readonly computeEnvironmentMaxVcpus: number;
    /**
     * Minimum VCPUs for Batch Compute Environment [0-16] for EC2 Batch Compute Environment (ignored for Fargate)
     */
    readonly computeEnvironmentMinVcpus: number;
    /**
     * IAM Partition (Select aws-us-gov for AWS GovCloud, otherwise leave as is)
     * @default aws
     */
    readonly iamPartition?: string;
    /**
     * Whether the metadata service is available. Can be 'enabled' or 'disabled'
     * @default enabled
     */
    readonly launchTemplateHttpEndpoint?: string;
    /**
     * The desired HTTP PUT response hop limit for instance metadata requests. Can be an integer from 1 to 64
     * @default 2
     */
    readonly launchTemplateHttpPutResponseHopLimit?: number;
    /**
     * Whether or not the metadata service requires session tokens, also referred to as Instance Metadata Service Version 2 (IMDSv2). Can be 'optional' or 'required'
     * @default optional
     */
    readonly launchTemplateHttpTokens?: string;
    /**
     * AMI id for launch template, defaults to allow AWS Batch to decide
     */
    readonly launchTemplateImageId?: string;
    /**
     * ID of the Metaflow VPC this SageMaker notebook instance is to be deployed in
     */
    readonly metaflowVpcId: string;
    /**
     * Prefix given to all AWS resources to differentiate between applications
     */
    readonly resourcePrefix: string;
    /**
     * Suffix given to all AWS resources to differentiate between environment and workspace
     */
    readonly resourceSuffix: string;
    /**
     * The standard tags to apply to every AWS resource.
     * The property type contains a map, they have special handling, please see {@link cdk.tf/module-map-inputs the docs}
     */
    readonly standardTags: {
        [key: string]: string;
    };
    /**
     * The first private subnet used for redundancy
     */
    readonly subnet1Id: string;
    /**
     * The second private subnet used for redundancy
     */
    readonly subnet2Id: string;
}
/**
 * Defines an MetaflowComputation based on a Terraform module
 *
 * Docs at Terraform Registry: {@link https://registry.terraform.io/modules/outerbounds/metaflow/aws/~> 0.9.4/submodules/computation outerbounds/metaflow/aws//modules/computation}
 */
export declare class MetaflowComputation extends TerraformModule {
    private readonly inputs;
    constructor(scope: Construct, id: string, config: MetaflowComputationConfig);
    get batchType(): string | undefined;
    set batchType(value: string | undefined);
    get computeEnvironmentAdditionalSecurityGroupIds(): string[] | undefined;
    set computeEnvironmentAdditionalSecurityGroupIds(value: string[] | undefined);
    get computeEnvironmentAllocationStrategy(): string | undefined;
    set computeEnvironmentAllocationStrategy(value: string | undefined);
    get computeEnvironmentDesiredVcpus(): number;
    set computeEnvironmentDesiredVcpus(value: number);
    get computeEnvironmentEgressCidrBlocks(): string[] | undefined;
    set computeEnvironmentEgressCidrBlocks(value: string[] | undefined);
    get computeEnvironmentInstanceTypes(): string[];
    set computeEnvironmentInstanceTypes(value: string[]);
    get computeEnvironmentMaxVcpus(): number;
    set computeEnvironmentMaxVcpus(value: number);
    get computeEnvironmentMinVcpus(): number;
    set computeEnvironmentMinVcpus(value: number);
    get iamPartition(): string | undefined;
    set iamPartition(value: string | undefined);
    get launchTemplateHttpEndpoint(): string | undefined;
    set launchTemplateHttpEndpoint(value: string | undefined);
    get launchTemplateHttpPutResponseHopLimit(): number | undefined;
    set launchTemplateHttpPutResponseHopLimit(value: number | undefined);
    get launchTemplateHttpTokens(): string | undefined;
    set launchTemplateHttpTokens(value: string | undefined);
    get launchTemplateImageId(): string | undefined;
    set launchTemplateImageId(value: string | undefined);
    get metaflowVpcId(): string;
    set metaflowVpcId(value: string);
    get resourcePrefix(): string;
    set resourcePrefix(value: string);
    get resourceSuffix(): string;
    set resourceSuffix(value: string);
    get standardTags(): {
        [key: string]: string;
    };
    set standardTags(value: {
        [key: string]: string;
    });
    get subnet1Id(): string;
    set subnet1Id(value: string);
    get subnet2Id(): string;
    set subnet2Id(value: string);
    get metaflowBatchJobQueueOutput(): string;
    get batchComputeEnvironmentSecurityGroupIdOutput(): string;
    get batchJobQueueArnOutput(): string;
    get ecsExecutionRoleArnOutput(): string;
    get ecsInstanceRoleArnOutput(): string;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
