import { TerraformModule, TerraformModuleUserConfig } from 'cdktf';
import { Construct } from 'constructs';
export interface MetaflowDatastoreConfig extends TerraformModuleUserConfig {
    /**
     * undefined
     * @default postgres
     */
    readonly dbEngine?: string;
    /**
     * undefined
     * @default 11
     */
    readonly dbEngineVersion?: string;
    /**
     * RDS instance type to launch for PostgresQL database.
     * @default db.t2.small
     */
    readonly dbInstanceType?: string;
    /**
     * Name of PostgresQL database for Metaflow service.
     * @default metaflow
     */
    readonly dbName?: string;
    /**
     * PostgresQL username; defaults to 'metaflow'
     * @default metaflow
     */
    readonly dbUsername?: string;
    /**
     * Empty S3 bucket before destroying via terraform destroy
     */
    readonly forceDestroyS3Bucket?: boolean;
    /**
     * The security group ID used by the MetaData service. We'll grant this access to our DB.
     */
    readonly metadataServiceSecurityGroupId: string;
    /**
     * ID of the Metaflow VPC this SageMaker notebook instance is to be deployed in
     */
    readonly metaflowVpcId: string;
    /**
     * Prefix given to all AWS resources to differentiate between applications
     */
    readonly resourcePrefix: string;
    /**
     * Suffix given to all AWS resources to differentiate between environment and workspace
     */
    readonly resourceSuffix: string;
    /**
     * The standard tags to apply to every AWS resource.
     * The property type contains a map, they have special handling, please see {@link cdk.tf/module-map-inputs the docs}
     */
    readonly standardTags: {
        [key: string]: string;
    };
    /**
     * First subnet used for availability zone redundancy
     */
    readonly subnet1Id: string;
    /**
     * Second subnet used for availability zone redundancy
     */
    readonly subnet2Id: string;
}
/**
 * Defines an MetaflowDatastore based on a Terraform module
 *
 * Docs at Terraform Registry: {@link https://registry.terraform.io/modules/outerbounds/metaflow/aws/~> 0.9.4/submodules/datastore outerbounds/metaflow/aws//modules/datastore}
 */
export declare class MetaflowDatastore extends TerraformModule {
    private readonly inputs;
    constructor(scope: Construct, id: string, config: MetaflowDatastoreConfig);
    get dbEngine(): string | undefined;
    set dbEngine(value: string | undefined);
    get dbEngineVersion(): string | undefined;
    set dbEngineVersion(value: string | undefined);
    get dbInstanceType(): string | undefined;
    set dbInstanceType(value: string | undefined);
    get dbName(): string | undefined;
    set dbName(value: string | undefined);
    get dbUsername(): string | undefined;
    set dbUsername(value: string | undefined);
    get forceDestroyS3Bucket(): boolean | undefined;
    set forceDestroyS3Bucket(value: boolean | undefined);
    get metadataServiceSecurityGroupId(): string;
    set metadataServiceSecurityGroupId(value: string);
    get metaflowVpcId(): string;
    set metaflowVpcId(value: string);
    get resourcePrefix(): string;
    set resourcePrefix(value: string);
    get resourceSuffix(): string;
    set resourceSuffix(value: string);
    get standardTags(): {
        [key: string]: string;
    };
    set standardTags(value: {
        [key: string]: string;
    });
    get subnet1Id(): string;
    set subnet1Id(value: string);
    get subnet2Id(): string;
    set subnet2Id(value: string);
    get metaflowDatastoreSysrootS3Output(): string;
    get metaflowDatatoolsS3RootOutput(): string;
    get databaseNameOutput(): string;
    get databasePasswordOutput(): string;
    get databaseUsernameOutput(): string;
    get datastoreS3BucketKmsKeyArnOutput(): string;
    get rdsMasterInstanceEndpointOutput(): string;
    get s3BucketArnOutput(): string;
    get s3BucketNameOutput(): string;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
