import { TerraformModule, TerraformModuleUserConfig } from 'cdktf';
import { Construct } from 'constructs';
export interface MetaflowMetadataServiceConfig extends TerraformModuleUserConfig {
    /**
     * List of CIDRs we want to grant access to our Metaflow Metadata Service. Usually this is our VPN's CIDR blocks.
     */
    readonly accessListCidrBlocks: string[];
    /**
     * The database name
     * @default metaflow
     */
    readonly databaseName?: string;
    /**
     * The database password
     */
    readonly databasePassword: string;
    /**
     * The database username
     */
    readonly databaseUsername: string;
    /**
     * The ARN of the KMS key used to encrypt the Metaflow datastore S3 bucket
     */
    readonly datastoreS3BucketKmsKeyArn: string;
    /**
     * Enable basic auth for API Gateway? (requires key export)
     * @default true
     */
    readonly enableApiBasicAuth?: boolean;
    /**
     * Enable API Gateway for public metadata service endpoint
     * @default true
     */
    readonly enableApiGateway?: boolean;
    /**
     * The IAM role that grants access to ECS and Batch services which we'll use as our Metadata Service API's execution_role for our Fargate instance
     */
    readonly fargateExecutionRoleArn: string;
    /**
     * IAM Partition (Select aws-us-gov for AWS GovCloud, otherwise leave as is)
     * @default aws
     */
    readonly iamPartition?: string;
    /**
     * Set to true if IAM partition is 'aws-us-gov'
     */
    readonly isGov?: boolean;
    /**
     * Container image for metadata service
     */
    readonly metadataServiceContainerImage?: string;
    /**
     * ECS task CPU unit for metadata service
     * @default 512
     */
    readonly metadataServiceCpu?: number;
    /**
     * ECS task memory in MiB for metadata service
     * @default 1024
     */
    readonly metadataServiceMemory?: number;
    /**
     * ID of the Metaflow VPC this SageMaker notebook instance is to be deployed in
     */
    readonly metaflowVpcId: string;
    /**
     * The database connection endpoint in address:port format
     */
    readonly rdsMasterInstanceEndpoint: string;
    /**
     * Prefix given to all AWS resources to differentiate between applications
     */
    readonly resourcePrefix: string;
    /**
     * Suffix given to all AWS resources to differentiate between environment and workspace
     */
    readonly resourceSuffix: string;
    /**
     * The ARN of the bucket we'll be using as blob storage
     */
    readonly s3BucketArn: string;
    /**
     * The standard tags to apply to every AWS resource.
     * The property type contains a map, they have special handling, please see {@link cdk.tf/module-map-inputs the docs}
     */
    readonly standardTags: {
        [key: string]: string;
    };
    /**
     * First private subnet used for availability zone redundancy
     */
    readonly subnet1Id: string;
    /**
     * Second private subnet used for availability zone redundancy
     */
    readonly subnet2Id: string;
    /**
     * The VPC CIDR blocks that we'll access list on our Metadata Service API to allow all internal communications
     */
    readonly vpcCidrBlocks: string[];
    /**
     * Enable public IP assignment for the Metadata Service. Typically you want this to be set to true if using public subnets as subnet1_id and subnet2_id, and false otherwise
     */
    readonly withPublicIp: boolean;
}
/**
 * Defines an MetaflowMetadataService based on a Terraform module
 *
 * Docs at Terraform Registry: {@link https://registry.terraform.io/modules/outerbounds/metaflow/aws/~> 0.9.4/submodules/metadata-service outerbounds/metaflow/aws//modules/metadata-service}
 */
export declare class MetaflowMetadataService extends TerraformModule {
    private readonly inputs;
    constructor(scope: Construct, id: string, config: MetaflowMetadataServiceConfig);
    get accessListCidrBlocks(): string[];
    set accessListCidrBlocks(value: string[]);
    get databaseName(): string | undefined;
    set databaseName(value: string | undefined);
    get databasePassword(): string;
    set databasePassword(value: string);
    get databaseUsername(): string;
    set databaseUsername(value: string);
    get datastoreS3BucketKmsKeyArn(): string;
    set datastoreS3BucketKmsKeyArn(value: string);
    get enableApiBasicAuth(): boolean | undefined;
    set enableApiBasicAuth(value: boolean | undefined);
    get enableApiGateway(): boolean | undefined;
    set enableApiGateway(value: boolean | undefined);
    get fargateExecutionRoleArn(): string;
    set fargateExecutionRoleArn(value: string);
    get iamPartition(): string | undefined;
    set iamPartition(value: string | undefined);
    get isGov(): boolean | undefined;
    set isGov(value: boolean | undefined);
    get metadataServiceContainerImage(): string | undefined;
    set metadataServiceContainerImage(value: string | undefined);
    get metadataServiceCpu(): number | undefined;
    set metadataServiceCpu(value: number | undefined);
    get metadataServiceMemory(): number | undefined;
    set metadataServiceMemory(value: number | undefined);
    get metaflowVpcId(): string;
    set metaflowVpcId(value: string);
    get rdsMasterInstanceEndpoint(): string;
    set rdsMasterInstanceEndpoint(value: string);
    get resourcePrefix(): string;
    set resourcePrefix(value: string);
    get resourceSuffix(): string;
    set resourceSuffix(value: string);
    get s3BucketArn(): string;
    set s3BucketArn(value: string);
    get standardTags(): {
        [key: string]: string;
    };
    set standardTags(value: {
        [key: string]: string;
    });
    get subnet1Id(): string;
    set subnet1Id(value: string);
    get subnet2Id(): string;
    set subnet2Id(value: string);
    get vpcCidrBlocks(): string[];
    set vpcCidrBlocks(value: string[]);
    get withPublicIp(): boolean;
    set withPublicIp(value: boolean);
    get metaflowServiceInternalUrlOutput(): string;
    get metaflowServiceUrlOutput(): string;
    get apiGatewayRestApiIdOutput(): string;
    get apiGatewayRestApiIdKeyIdOutput(): string;
    get metadataServiceSecurityGroupIdOutput(): string;
    get metadataSvcEcsTaskRoleArnOutput(): string;
    get migrationFunctionArnOutput(): string;
    get networkLoadBalancerDnsNameOutput(): string;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
