import { TerraformModule, TerraformModuleUserConfig } from 'cdktf';
import { Construct } from 'constructs';
export interface MetaflowStepFunctionsConfig extends TerraformModuleUserConfig {
    /**
     * When true step function infrastructure is provisioned.
     */
    readonly active?: boolean;
    /**
     * Batch job queue arn
     */
    readonly batchJobQueueArn: string;
    /**
     * IAM Partition (Select aws-us-gov for AWS GovCloud, otherwise leave as is)
     * @default aws
     */
    readonly iamPartition?: string;
    /**
     * Prefix given to all AWS resources to differentiate between applications
     */
    readonly resourcePrefix: string;
    /**
     * Suffix given to all AWS resources to differentiate between environment and workspace
     */
    readonly resourceSuffix: string;
    /**
     * arn of the metaflow datastore s3 bucket
     */
    readonly s3BucketArn: string;
    /**
     * arn of the metaflow datastore s3 bucket's kms key
     */
    readonly s3BucketKmsArn: string;
    /**
     * The standard tags to apply to every AWS resource.
     * The property type contains a map, they have special handling, please see {@link cdk.tf/module-map-inputs the docs}
     */
    readonly standardTags: {
        [key: string]: string;
    };
}
/**
 * Defines an MetaflowStepFunctions based on a Terraform module
 *
 * Docs at Terraform Registry: {@link https://registry.terraform.io/modules/outerbounds/metaflow/aws/~> 0.9.4/submodules/step-functions outerbounds/metaflow/aws//modules/step-functions}
 */
export declare class MetaflowStepFunctions extends TerraformModule {
    private readonly inputs;
    constructor(scope: Construct, id: string, config: MetaflowStepFunctionsConfig);
    get active(): boolean | undefined;
    set active(value: boolean | undefined);
    get batchJobQueueArn(): string;
    set batchJobQueueArn(value: string);
    get iamPartition(): string | undefined;
    set iamPartition(value: string | undefined);
    get resourcePrefix(): string;
    set resourcePrefix(value: string);
    get resourceSuffix(): string;
    set resourceSuffix(value: string);
    get s3BucketArn(): string;
    set s3BucketArn(value: string);
    get s3BucketKmsArn(): string;
    set s3BucketKmsArn(value: string);
    get standardTags(): {
        [key: string]: string;
    };
    set standardTags(value: {
        [key: string]: string;
    });
    get metaflowEventbridgeRoleArnOutput(): string;
    get metaflowStepFunctionsDynamodbPolicyOutput(): string;
    get metaflowStepFunctionsDynamodbTableArnOutput(): string;
    get metaflowStepFunctionsDynamodbTableNameOutput(): string;
    get metaflowStepFunctionsRoleArnOutput(): string;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
