import { TerraformModule, TerraformModuleUserConfig } from 'cdktf';
import { Construct } from 'constructs';
export interface MetaflowUiConfig extends TerraformModuleUserConfig {
    /**
     * METAFLOW_DATASTORE_SYSROOT_S3 value
     */
    readonly metaflowDatastoreSysrootS3: string;
    /**
     * Defines whether the ALB is internal
     */
    readonly albInternal?: boolean;
    /**
     * SSL certificate ARN. The certificate will be used by the UI load balancer.
     */
    readonly certificateArn: string;
    /**
     * The database name
     * @default metaflow
     */
    readonly databaseName?: string;
    /**
     * The database password
     */
    readonly databasePassword: string;
    /**
     * The database username
     */
    readonly databaseUsername: string;
    /**
     * The ARN of the KMS key used to encrypt the Metaflow datastore S3 bucket
     */
    readonly datastoreS3BucketKmsKeyArn: string;
    /**
     * Additional environment variables for UI backend container
     * @default [object Object]
     * The property type contains a map, they have special handling, please see {@link cdk.tf/module-map-inputs the docs}
     */
    readonly extraUiBackendEnvVars?: {
        [key: string]: string;
    };
    /**
     * Additional environment variables for UI static app
     * @default [object Object]
     * The property type contains a map, they have special handling, please see {@link cdk.tf/module-map-inputs the docs}
     */
    readonly extraUiStaticEnvVars?: {
        [key: string]: string;
    };
    /**
     * This role allows Fargate to pull container images and logs. We'll use it as execution_role for our Fargate task
     */
    readonly fargateExecutionRoleArn: string;
    /**
     * IAM Partition (Select aws-us-gov for AWS GovCloud, otherwise leave as is)
     * @default aws
     */
    readonly iamPartition?: string;
    /**
     * Set to true if IAM partition is 'aws-us-gov'
     */
    readonly isGov?: boolean;
    /**
     * The security group ID used by the MetaData service. This security group should allow connections to the RDS instance.
     */
    readonly metadataServiceSecurityGroupId: string;
    /**
     * VPC to deploy services into
     */
    readonly metaflowVpcId: string;
    /**
     * The database connection endpoint in address:port format
     */
    readonly rdsMasterInstanceEndpoint: string;
    /**
     * Prefix given to all AWS resources to differentiate between applications
     */
    readonly resourcePrefix: string;
    /**
     * Suffix given to all AWS resources to differentiate between environment and workspace
     */
    readonly resourceSuffix: string;
    /**
     * The ARN of the bucket used for Metaflow datastore
     */
    readonly s3BucketArn: string;
    /**
     * The standard tags to apply to every AWS resource.
     * The property type contains a map, they have special handling, please see {@link cdk.tf/module-map-inputs the docs}
     */
    readonly standardTags: {
        [key: string]: string;
    };
    /**
     * First private subnet used for availability zone redundancy
     */
    readonly subnet1Id: string;
    /**
     * Second private subnet used for availability zone redundancy
     */
    readonly subnet2Id: string;
    /**
     * A list of CIDRs the UI will be available to
     * @default
     */
    readonly uiAllowList?: string[];
    /**
     * Container image for UI backend
     */
    readonly uiBackendContainerImage?: string;
    /**
     * Container image for the UI frontend app
     */
    readonly uiStaticContainerImage?: string;
}
/**
 * Defines an MetaflowUi based on a Terraform module
 *
 * Docs at Terraform Registry: {@link https://registry.terraform.io/modules/outerbounds/metaflow/aws/~> 0.9.4/submodules/ui outerbounds/metaflow/aws//modules/ui}
 */
export declare class MetaflowUi extends TerraformModule {
    private readonly inputs;
    constructor(scope: Construct, id: string, config: MetaflowUiConfig);
    get metaflowDatastoreSysrootS3(): string;
    set metaflowDatastoreSysrootS3(value: string);
    get albInternal(): boolean | undefined;
    set albInternal(value: boolean | undefined);
    get certificateArn(): string;
    set certificateArn(value: string);
    get databaseName(): string | undefined;
    set databaseName(value: string | undefined);
    get databasePassword(): string;
    set databasePassword(value: string);
    get databaseUsername(): string;
    set databaseUsername(value: string);
    get datastoreS3BucketKmsKeyArn(): string;
    set datastoreS3BucketKmsKeyArn(value: string);
    get extraUiBackendEnvVars(): {
        [key: string]: string;
    } | undefined;
    set extraUiBackendEnvVars(value: {
        [key: string]: string;
    } | undefined);
    get extraUiStaticEnvVars(): {
        [key: string]: string;
    } | undefined;
    set extraUiStaticEnvVars(value: {
        [key: string]: string;
    } | undefined);
    get fargateExecutionRoleArn(): string;
    set fargateExecutionRoleArn(value: string);
    get iamPartition(): string | undefined;
    set iamPartition(value: string | undefined);
    get isGov(): boolean | undefined;
    set isGov(value: boolean | undefined);
    get metadataServiceSecurityGroupId(): string;
    set metadataServiceSecurityGroupId(value: string);
    get metaflowVpcId(): string;
    set metaflowVpcId(value: string);
    get rdsMasterInstanceEndpoint(): string;
    set rdsMasterInstanceEndpoint(value: string);
    get resourcePrefix(): string;
    set resourcePrefix(value: string);
    get resourceSuffix(): string;
    set resourceSuffix(value: string);
    get s3BucketArn(): string;
    set s3BucketArn(value: string);
    get standardTags(): {
        [key: string]: string;
    };
    set standardTags(value: {
        [key: string]: string;
    });
    get subnet1Id(): string;
    set subnet1Id(value: string);
    get subnet2Id(): string;
    set subnet2Id(value: string);
    get uiAllowList(): string[] | undefined;
    set uiAllowList(value: string[] | undefined);
    get uiBackendContainerImage(): string | undefined;
    set uiBackendContainerImage(value: string | undefined);
    get uiStaticContainerImage(): string | undefined;
    set uiStaticContainerImage(value: string | undefined);
    get albArnOutput(): string;
    get albDnsNameOutput(): string;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
